@@ -19,11 +19,12 @@ from __future__ import absolute_import
 
 import logging
 import os.path
-from .models.folder import Folder
+
 from . import fresh_operation
+from .models.folder import Folder
 
 
-class Folders(object):
+class Folders:
 
     """Class for handling Folders operations."""
 
@@ -32,8 +33,9 @@ class Folders(object):
         self._base = smartsheet_obj
         self._log = logging.getLogger(__name__)
 
-    def copy_folder(self, folder_id, container_destination_obj,
-                    include=None, skip_remap=None, omit=None):
+    def copy_folder(
+        self, folder_id, container_destination_obj, include=None, skip_remap=None
+    ):
         """Creates a copy of the specified Folder.
 
         Args:
@@ -42,26 +44,23 @@ class Folders(object):
                 (ContainerDestination): Container Destination object.
             include (list[str]): A comma separated list of
                 elements to copy. Valid list values: attachments,
-                cellLinks, data, discussions, filters, forms, ruleRecipients,
+                attachments, cellLinks, data, discussions, filters, forms, ruleRecipients,
                 rules, shares, all (deprecated).
             skip_remap (list[str]): A comma separated list
                 of references to NOT re-map for the newly created resource.
                 Valid list items: cellLinks, reports, sheetHyperlinks, sights
-            omit (list[str]): A comma separated list of elements to omit.
-                The only current valid item is sheetHyperlinks
 
         Returns:
             Result
         """
-        _op = fresh_operation('copy_folder')
-        _op['method'] = 'POST'
-        _op['path'] = '/folders/' + str(folder_id) + '/copy'
-        _op['query_params']['include'] = include
-        _op['query_params']['skipRemap'] = skip_remap
-        _op['query_params']['omit'] = omit
-        _op['json'] = container_destination_obj
+        _op = fresh_operation("copy_folder")
+        _op["method"] = "POST"
+        _op["path"] = "/folders/" + str(folder_id) + "/copy"
+        _op["query_params"]["include"] = include
+        _op["query_params"]["skipRemap"] = skip_remap
+        _op["json"] = container_destination_obj
 
-        expected = ['Result', 'Folder']
+        expected = ["Result", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -79,16 +78,14 @@ class Folders(object):
             Result
         """
         if isinstance(folder_obj, str):
-            folder_obj = Folder({
-                'name': folder_obj
-            })
+            folder_obj = Folder({"name": folder_obj})
 
-        _op = fresh_operation('create_folder_in_folder')
-        _op['method'] = 'POST'
-        _op['path'] = '/folders/' + str(folder_id) + '/folders'
-        _op['json'] = folder_obj
+        _op = fresh_operation("create_folder_in_folder")
+        _op["method"] = "POST"
+        _op["path"] = "/folders/" + str(folder_id) + "/folders"
+        _op["json"] = folder_obj
 
-        expected = ['Result', 'Folder']
+        expected = ["Result", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -105,12 +102,12 @@ class Folders(object):
         Returns:
             Result
         """
-        _op = fresh_operation('create_sheet_in_folder')
-        _op['method'] = 'POST'
-        _op['path'] = '/folders/' + str(folder_id) + '/sheets'
-        _op['json'] = sheet_obj
+        _op = fresh_operation("create_sheet_in_folder")
+        _op["method"] = "POST"
+        _op["path"] = "/folders/" + str(folder_id) + "/sheets"
+        _op["json"] = sheet_obj
 
-        expected = ['Result', 'Sheet']
+        expected = ["Result", "Sheet"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -118,8 +115,7 @@ class Folders(object):
         return response
 
     # pylint: disable=invalid-name
-    def create_sheet_in_folder_from_template(self, folder_id, sheet_obj,
-                                             include=None):
+    def create_sheet_in_folder_from_template(self, folder_id, sheet_obj, include=None):
         """Create a Sheet in the specified Folder from the specified Template.
 
         The Sheet object should be limited to the following
@@ -143,13 +139,13 @@ class Folders(object):
         Returns:
             Result
         """
-        _op = fresh_operation('create_sheet_in_folder_from_template')
-        _op['method'] = 'POST'
-        _op['path'] = '/folders/' + str(folder_id) + '/sheets'
-        _op['query_params']['include'] = include
-        _op['json'] = sheet_obj
+        _op = fresh_operation("create_sheet_in_folder_from_template")
+        _op["method"] = "POST"
+        _op["path"] = "/folders/" + str(folder_id) + "/sheets"
+        _op["query_params"]["include"] = include
+        _op["json"] = sheet_obj
 
-        expected = ['Result', 'Sheet']
+        expected = ["Result", "Sheet"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -167,11 +163,11 @@ class Folders(object):
         Returns:
             Result
         """
-        _op = fresh_operation('delete_folder')
-        _op['method'] = 'DELETE'
-        _op['path'] = '/folders/' + str(folder_id)
+        _op = fresh_operation("delete_folder")
+        _op["method"] = "DELETE"
+        _op["path"] = "/folders/" + str(folder_id)
 
-        expected = ['Result', None]
+        expected = ["Result", None]
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
 
@@ -189,19 +185,18 @@ class Folders(object):
         Returns:
             Folder
         """
-        _op = fresh_operation('get_folder')
-        _op['method'] = 'GET'
-        _op['path'] = '/folders/' + str(folder_id)
-        _op['query_params']['include'] = include
+        _op = fresh_operation("get_folder")
+        _op["method"] = "GET"
+        _op["path"] = "/folders/" + str(folder_id)
+        _op["query_params"]["include"] = include
 
-        expected = 'Folder'
+        expected = "Folder"
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
 
         return response
 
-    def list_folders(self, folder_id, page_size=None, page=None,
-                     include_all=None):
+    def list_folders(self, folder_id, page_size=None, page=None, include_all=None):
         """Get a list of top-level child Folders within the specified Folder.
 
         Args:
@@ -215,14 +210,14 @@ class Folders(object):
         Returns:
             IndexResult
         """
-        _op = fresh_operation('list_folders')
-        _op['method'] = 'GET'
-        _op['path'] = '/folders/' + str(folder_id) + '/folders'
-        _op['query_params']['pageSize'] = page_size
-        _op['query_params']['page'] = page
-        _op['query_params']['includeAll'] = include_all
+        _op = fresh_operation("list_folders")
+        _op["method"] = "GET"
+        _op["path"] = "/folders/" + str(folder_id) + "/folders"
+        _op["query_params"]["pageSize"] = page_size
+        _op["query_params"]["page"] = page
+        _op["query_params"]["includeAll"] = include_all
 
-        expected = ['IndexResult', 'Folder']
+        expected = ["IndexResult", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -240,12 +235,12 @@ class Folders(object):
         Returns:
             Result
         """
-        _op = fresh_operation('move_folder')
-        _op['method'] = 'POST'
-        _op['path'] = '/folders/' + str(folder_id) + '/move'
-        _op['json'] = container_destination_obj
+        _op = fresh_operation("move_folder")
+        _op["method"] = "POST"
+        _op["path"] = "/folders/" + str(folder_id) + "/move"
+        _op["json"] = container_destination_obj
 
-        expected = ['Result', 'Folder']
+        expected = ["Result", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
@@ -263,23 +258,28 @@ class Folders(object):
             Result
         """
         if isinstance(folder_obj, str):
-            folder_obj = Folder({
-                'name': folder_obj
-            })
+            folder_obj = Folder({"name": folder_obj})
 
-        _op = fresh_operation('update_folder')
-        _op['method'] = 'PUT'
-        _op['path'] = '/folders/' + str(folder_id)
-        _op['json'] = folder_obj
+        _op = fresh_operation("update_folder")
+        _op["method"] = "PUT"
+        _op["path"] = "/folders/" + str(folder_id)
+        _op["json"] = folder_obj
 
-        expected = ['Result', 'Folder']
+        expected = ["Result", "Folder"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
 
         return response
 
-    def import_csv_sheet(self, folder_id, file, sheet_name=None, header_row_index=None, primary_column_index=None ):
+    def import_csv_sheet(
+        self,
+        folder_id,
+        file,
+        sheet_name=None,
+        header_row_index=None,
+        primary_column_index=None,
+    ):
         """Imports a sheet in the specified folder.
 
         Args:
@@ -291,16 +291,29 @@ class Folders(object):
 
         Returns:
             Result
-            """
-        if not all(val is not None for val in ['folder_id', 'file']):
+        """
+        if not all(val is not None for val in ["folder_id", "file"]):
             raise ValueError(
-                ('One or more required values '
-                 'are missing from call to ' + __name__))
+                ("One or more required values are missing from call to " + __name__)
+            )
 
-        return self._import_sheet(folder_id, file, "text/csv",
-                                  sheet_name, header_row_index, primary_column_index)
+        return self._import_sheet(
+            folder_id,
+            file,
+            "text/csv",
+            sheet_name,
+            header_row_index,
+            primary_column_index,
+        )
 
-    def import_xlsx_sheet(self, folder_id, file, sheet_name=None, header_row_index=None, primary_column_index=None ):
+    def import_xlsx_sheet(
+        self,
+        folder_id,
+        file,
+        sheet_name=None,
+        header_row_index=None,
+        primary_column_index=None,
+    ):
         """Imports a sheet in the specified folder.
 
         Args:
@@ -312,36 +325,50 @@ class Folders(object):
 
         Returns:
             Result
-            """
-        if not all(val is not None for val in ['folder_id', 'file']):
+        """
+        if not all(val is not None for val in ["folder_id", "file"]):
             raise ValueError(
-                ('One or more required values '
-                 'are missing from call to ' + __name__))
+                ("One or more required values are missing from call to " + __name__)
+            )
 
-        return self._import_sheet(folder_id, file,
-                                  "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
-                                  sheet_name, header_row_index, primary_column_index)
+        return self._import_sheet(
+            folder_id,
+            file,
+            "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
+            sheet_name,
+            header_row_index,
+            primary_column_index,
+        )
 
-    def _import_sheet(self, folder_id, file, file_type, sheet_name, header_row_index, primary_column_index):
+    def _import_sheet(
+        self,
+        folder_id,
+        file,
+        file_type,
+        sheet_name,
+        header_row_index,
+        primary_column_index,
+    ):
         """Internal function used to import sheet"""
 
         if sheet_name is None:
             head, tail = os.path.split(file)
             sheet_name = tail or os.path.basename(head)
 
-        _data = open(file, 'rb').read()
+        _data = open(file, "rb").read()
+        _op = fresh_operation("import_sheet_into_folder")
+        _op["method"] = "POST"
+        _op["path"] = "/folders/" + str(folder_id) + "/sheets/import"
+        _op["headers"] = {
+            "content-type": file_type,
+            "content-disposition": "attachment",
+        }
+        _op["form_data"] = _data
+        _op["query_params"]["sheetName"] = sheet_name
+        _op["query_params"]["headerRowIndex"] = header_row_index
+        _op["query_params"]["primaryColumnIndex"] = primary_column_index
 
-        _op = fresh_operation('import_sheet_into_folder')
-        _op['method'] = 'POST'
-        _op['path'] = '/folders/' + str(folder_id) + '/sheets/import'
-        _op['headers'] = {'content-type': file_type,
-                          'content-disposition': 'attachment'}
-        _op['form_data'] = _data
-        _op['query_params']['sheetName'] = sheet_name
-        _op['query_params']['headerRowIndex'] = header_row_index
-        _op['query_params']['primaryColumnIndex'] = primary_column_index
-
-        expected = ['Result', 'Sheet']
+        expected = ["Result", "Sheet"]
 
         prepped_request = self._base.prepare_request(_op)
         response = self._base.request(prepped_request, expected, _op)
