@@ -17,20 +17,22 @@
 
 from __future__ import absolute_import
 
+from ..types import (Boolean, EnumeratedValue, Number, String, Timestamp,
+                     TypedList, TypedObject, json)
+from ..util import deserialize, serialize
 from .enums import AccessLevel
+from .source import Source
 from .widget import Widget
-from ..types import *
-from ..util import serialize
-from ..util import deserialize
 
 
-class Sight(object):
+class Sight:
 
     """Smartsheet Sight data model."""
 
     def __init__(self, props=None, base_obj=None):
         from .workspace import Workspace
-        """Initialize the Sight model."""
+
+        # Initialize the Sight model.
         self._base = None
         if base_obj is not None:
             self._base = base_obj
@@ -44,6 +46,7 @@ class Sight(object):
         self._modified_at = Timestamp()
         self._name = String()
         self._permalink = String()
+        self._source = TypedObject(Source)
         self._widgets = TypedList(Widget)
         self._workspace = TypedObject(Workspace)
 
@@ -55,16 +58,16 @@ class Sight(object):
         self.__initialized = True
 
     def __getattr__(self, key):
-        if key == 'id':
+        if key == "id":
             return self.id_
         else:
             raise AttributeError(key)
 
     def __setattr__(self, key, value):
-        if key == 'id':
+        if key == "id":
             self.id_ = value
         else:
-            super(Sight, self).__setattr__(key, value)
+            super().__setattr__(key, value)
 
     @property
     def access_level(self):
@@ -138,6 +141,14 @@ class Sight(object):
     def permalink(self, value):
         self._permalink.value = value
 
+    @property
+    def source(self):
+        return self._source.value
+
+    @source.setter
+    def source(self, value):
+        self._source.value = value
+
     @property
     def widgets(self):
         return self._widgets
