@@ -1,11 +1,11 @@
 # pylint: disable=C0103,W0232
 
 import pytest
-from smartsheet.models import Sheet
+from smartsheet.models import Sheet, ExplicitNull
 from smartsheet.exceptions import ApiError
-
 from mock_api_test_helper import MockApiTestHelper, clean_api_error
 
+
 class TestMockApiSheets(MockApiTestHelper):
     @clean_api_error
     def test_list_sheets(self):
@@ -27,13 +27,13 @@ class TestMockApiSheets(MockApiTestHelper):
 
         assert sheets[0].owner == "john.doe@smartsheet.com"
 
-    @clean_api_error 
+    @clean_api_error
     def test_create_sheet_invalid_no_columns(self):
         self.client.as_test_scenario('Create Sheet - Invalid - No Columns')
 
         new_sheet = Sheet({
             "name": "New Sheet",
-            "columns": []
+            "columns": ExplicitNull()
         })
 
         with pytest.raises(ApiError) as e:
